#2017_eseg08_silc_long.R EU-SILC Panel data
#R Script gegerated under R Version 4.1.2

#Judith Gilsbach/Wirth, Heike (2022): 2017_eseg08_silc_long.R
#https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling

#Longitudinal data.
#This syntax generates European Socio-Economic Groups (ESEG) based on ISCO08 for EU-SILC Data
#using the P-File (personal data) & R-FILE (personal register data).
#ESeG_1 (less detailed)
#ESeG_2 (detailed)

#For details on ESeG please see 
#Meron, Monique et al. (2014)
#Final Report of the ESSnet on the harmonisation and implementation of a 
#European socio-economic classification: 
#European Socio-economic Groups (ESeG)
#Links:
# [0] https://ec.europa.eu/eurostat/cros/content/eseg-report-technicaldocuments_en
# [1] https://ec.europa.eu/eurostat/cros/system/files/ESEG-Report-TechnicalAnnexes_0.zip_en
# [2] https://ec.europa.eu/eurostat/cros/content/eseg_en


#This R-code is free software: you can redistribute it and/or modify
#it under the terms of the GNU Affero General Public License as
#published by the Free Software Foundation, either version 3 of the
#License, or (at your option) any later version.

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#GNU Affero General Public License for more details.

#<https://www.gnu.org/licenses/>.

#Currently this Script is based on the Stata-Files:
# EU-SILC Panel data P-File (personal data):
#  UDB_l17P_ver 2021_09.csv
# EU-SILC Panel data R-File (personal register data):
#  UDB_l17R_ver 2021_09.csv
#For transforming the CSV-data (as released by Eurostat) into Stata-data (*.dta),
#please use the corresponding STATA Command Syntax File published at 
#http://www.gesis.org/missy/eu/setups/EU-SILC

#(c) GESIS 02/23/2022
#GESIS - Leibniz Institute for the Social Sciences
#German Microdata Lab 
#Judith Gilsbach, Heike Wirth
#http://www.gesis.org/en/institute/
#https://www.gesis.org/gml/european-microdata/eu-silc/
#https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling

#Contact: heike.wirth@gesis.org

#start with clean workspace
rm(list = ls(all = TRUE))

#set working directory
setwd("Path to your directory")

#load packages, adjustments may be necessary if you're working in an institutional environment
library(tidyverse)
library(haven)
library(dplyr)

#Read Data
P2017_long <- read_dta("Specify the name of the P-file dataset and the path if not in working directory")
P2017_long <- as.data.frame(P2017_long) %>%
  select(PB010, PB020, PL051, PL040, PL031, PB140, PX030, PB030)
R2017_long <- read_dta("Specify the name of the R-file dataset and the path if not in working directory")
R2017_long <- as.data.frame(R2017_long) %>%
  select(RB010, RB020, RB040, RB030, RX010)

##################################################################################
#  Good to know
#
#      There are country specific anonymisation rules in EU-SILC for DE, MT, SI and PT 
#      DE, MT, SI: ISCO08 is provided only for major groups (1-digit)
#      PT: ISCO08 sub-major groups 11, 12, 13 are mereged with sub-major group 14  
#
#   => MT: For Germany, Malta and Slovenia there is no ESeG generated
#   => PT: For Portugal there is no differentiation between higher and lower Manager 
#
#   Unemployed persons (PL031=5) are classified according to their last job.
#      If there is no information available, unemployed persons are classified as non-active
#      Persons 
#
#   Non-active persons (PL031=6,7,8,10,11) are split into two groups.
#   Group 8: retired people and non-employed people aged 65 or more
#     
#   Group 9: Non-active persons aged less than 65 years who couldn't be classified according to their
#            last job in one of seven ESEG groups
# 
##################################################################################

##################################################################################
#
#Variables used
# PB020: Country (alphanumeric)
# PL051: ISCO08  (2-digit) current/last; DE, MT, SI: 1-digit
# PL040: Status in employment (current/last) => family workers are classified as self-employed
# PL031: self-defined current economic status (current)
# Age = either constructed by using PB140: Year of birth & PB010  year of data collection
# RX010: Age at time of interview (preferred option)
# Further variables needed when merging R-File and P-File
# RB010 RB020 RB040 RB030 RX010
# PB010 PB020 PX030 PB030
#
##################################################################################

#Prepare Datasets for merging
P2017_long$ID_Merge <- paste(as.character(P2017_long$PB010), P2017_long$PB020, as.character(P2017_long$PX030), as.character(P2017_long$PB030), sep = "_")
colnames(R2017_long) <- c("PB010", "PB020", "PX030", "PB030", "age")
R2017_long$ID_Merge <- paste(as.character(R2017_long$PB010), R2017_long$PB020, as.character(R2017_long$PX030), as.character(R2017_long$PB030), sep = "_")
#Reduce R-File and rename age variable
R2017_long <- R2017_long %>%
  select(ID_Merge, age)

#Merge to P-File
P2017_long <- left_join(P2017_long, R2017_long, by = "ID_Merge")

#Rename isco08
P2017_long$isco08 <- P2017_long$PL051

P2017_long$isco08[P2017_long$PB020 == "MT"] <- NA
P2017_long$isco08[P2017_long$PB020 == "SI" & P2017_long$PB010 >= 2014] <- NA
P2017_long$isco08[P2017_long$PB020 == "DE" & P2017_long$PB010 >= 2015] <- NA

#Generating employment status variable
#Family workers are defined as self-employed 

P2017_long$sta <- P2017_long$PL040
P2017_long$sta[P2017_long$PL040 == 1 | P2017_long$PL040 == 2 | P2017_long$PL040 == 4] <- 1
P2017_long$sta[P2017_long$PL040 == 3] <- 2

P2017_long$sta_label <- NA
P2017_long$sta_label[P2017_long$sta == 1]<- "self-employed"
P2017_long$sta_label[P2017_long$sta == 2]<- "employed"

table(P2017_long$sta_label, useNA = "always")


#### eseg_1 = aggregated level 

P2017_long$eseg_1 <- NA

# Assigning eseg to respondents with self-defined current economic status (PL031): self-employed, employed, unemployed, in compulsory military community or service
P2017_long$eseg_1[((P2017_long$isco08 >= 11 & P2017_long$isco08 <= 14) & (P2017_long$sta == 1 | P2017_long$sta == 2)) | 
                    ((P2017_long$isco08 == 01 & P2017_long$sta == 2) & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9))] <- 1
P2017_long$eseg_1[((P2017_long$isco08 >= 21 & P2017_long$isco08 <= 26) & (P2017_long$sta == 1 | P2017_long$sta == 2)) & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 2

P2017_long$eseg_1[((P2017_long$isco08 >= 31 & P2017_long$isco08 <= 35) | P2017_long$isco08 == 2) & P2017_long$sta == 2 & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 3

P2017_long$eseg_1[(P2017_long$isco08 >= 31 & P2017_long$isco08 <= 96) & P2017_long$sta == 1 & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 4
P2017_long$eseg_1[((P2017_long$isco08 >= 41 & P2017_long$isco08 <= 44) | P2017_long$isco08 == 53 | P2017_long$isco08 == 54 | P2017_long$isco08 == 3) & P2017_long$sta == 2 &
                    ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 5
P2017_long$eseg_1[(P2017_long$isco08 >= 71 & P2017_long$isco08 <= 83) & P2017_long$sta == 2 & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 6
P2017_long$eseg_1[((P2017_long$isco08 == 51 | P2017_long$isco08 == 52) | (P2017_long$isco08 >= 61 & P2017_long$isco08 <= 63) | (P2017_long$isco08 >= 91 & P2017_long$isco08 <= 96))
                  & P2017_long$sta == 2 & ((P2017_long$PL031 >= 1 & P2017_long$PL031 <= 5) | P2017_long$PL031 == 9)] <- 7

# Respondents <65, unemployed, no eseg assigned yet are set to eseg 9 'other non-employed persons'
P2017_long$eseg_1[is.na(P2017_long$eseg_1) & P2017_long$age < 65 & P2017_long$PL031 == 5] <- 9

# All other respondents, unemployed and neither in eseg 1-7 nor in eseg 9 are set to eseg 8 'Retired persons'
P2017_long$eseg_1[is.na(P2017_long$eseg_1) &  P2017_long$PL031 == 5] <- 8

# Respondents  <65 and non-employed according to PL031 (6,8,10,11) are set to eseg 9 'other non-employed persons'
P2017_long$eseg_1[((P2017_long$PL031 == 6 | P2017_long$PL031 == 8 | P2017_long$PL031 == 10 | P2017_long$PL031 == 11) & P2017_long$age <= 64 ) | P2017_long$age <= 14] <- 9

# Respondents  >64 and non-employed  are set to eseg 8  'Retired persons'
P2017_long$eseg_1[P2017_long$PL031 == 7 | ((P2017_long$age >= 65 & P2017_long$age <99) & (P2017_long$PL031 == 5 | P2017_long$PL031 == 6 | P2017_long$PL031 == 7 | P2017_long$PL031 == 8 | P2017_long$PL031 == 10 | P2017_long$PL031 == 11 | is.na(P2017_long$PL031)))] <- 8

#ESeG for Malta is set to missing value,  because of country specific anonymisation (ISCO08 only available as 1-digit)
P2017_long$eseg_1[P2017_long$PB020 == "MT"] <- NA
P2017_long$eseg_1[P2017_long$PB020 == "SI" & P2017_long$PB010 >= 2014] <- NA
P2017_long$eseg_1[P2017_long$PB020 == "DE" & P2017_long$PB010 >= 2015] <- NA

#generate label varaible for eseg_1
P2017_long$eseg_1_label <- NA
P2017_long$eseg_1_label[P2017_long$eseg_1 == 1] <- "1 Manager"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 2] <- "2 Professionals"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 3] <- "3 Technicians and associated professeional employees"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 4] <- "4 Small entrepreneur"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 5] <- "5 Clerks and skilled service employees"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 6] <- "6 Industrial skilled employees"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 7] <- "7 Less skilled employees"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 8] <- "8 Retired persons and non-employed people >=65"
P2017_long$eseg_1_label[P2017_long$eseg_1 == 9] <- "9 Other non-employed persons aged < 65"

#Frequency Table eseg_1
table_eseg_1 <- data.frame(table(P2017_long$eseg_1_label, useNA = "always"))
View(table_eseg_1)

#### eseg_2 = detailed level 

P2017_long$eseg_2 <- NA

##Definition
#1	Managers
#1.1	Higher managerial self-employed  (ISCO 11, 12, 13 and status=se)
#1.2	Lower managerial self-employed  (ISCO 14 and status=se)
#1.3	Higher managerial employees   (ISCO 11, 12, 13 and 01 and status=e)
#1.4	Lower managerial employees   (ISCO 14 and status=e)

P2017_long$eseg_2[(P2017_long$isco08 == 11 | P2017_long$isco08 == 12 | P2017_long$isco08 == 13) & P2017_long$sta == 1 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 11
P2017_long$eseg_2[P2017_long$isco08 == 14 & P2017_long$sta == 1 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 12
P2017_long$eseg_2[(P2017_long$isco08 == 01 | P2017_long$isco08 == 11 | P2017_long$isco08 == 12 | P2017_long$isco08 == 13) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 13
P2017_long$eseg_2[P2017_long$isco08 == 14 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 14

##Definition
#2	Professionals
#2.1	Science, engineering and information and communications technology (ICT) professionnals (ISCO 21,25)
#2.2	Health professionals  (ISCO 22)
#2.3	Business and administration professionals  (ISCO 24)
#2.4	Legal, social and cultural professionals  (ISCO 26)
#2.5	Teaching professionals  (ISCO 23)  

P2017_long$eseg_2[(P2017_long$isco08 == 21 | P2017_long$isco08 == 25) & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 21
P2017_long$eseg_2[P2017_long$isco08 == 22 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 22
P2017_long$eseg_2[P2017_long$isco08 == 24 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 23
P2017_long$eseg_2[P2017_long$isco08 == 26 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 24
P2017_long$eseg_2[P2017_long$isco08 == 23 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 25

##Definition
#3	Technicians and associated professionals employees (status= e)
#3.1	Science, engineering and ICT technicians and associated professionals (ISCO 31, 35)
#3.2	Health associate professionals  (ISCO 32)
#3.3	Business and administration associate professionals  (ISCO 33)
#3.4	Legal, social and cultural associate professionals  (ISCO 34)
#3.5	Non-commissioned armed forces officers  (ISCO 02 )

P2017_long$eseg_2[(P2017_long$isco08 == 31 | P2017_long$isco08 == 35) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 31
P2017_long$eseg_2[P2017_long$isco08 == 32 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 32
P2017_long$eseg_2[P2017_long$isco08 == 33 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 33
P2017_long$eseg_2[P2017_long$isco08 == 34 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 34
P2017_long$eseg_2[P2017_long$isco08 == 02 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 35

##Definition
#4	Small entrepreneurs  (status= se)
#4.1	Skilled agricultural self employed workers  (ISCO 6)
#4.2	Technicians, clerical support, services and sales self employed workers  (ISCO 3, 4, 5)
#4.3	Craft and related trades self employed workers  (ISCO 7, 8, 9)

P2017_long$eseg_2[(P2017_long$isco08 >= 61 & P2017_long$isco08 <= 63) & P2017_long$sta == 1 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 41
P2017_long$eseg_2[(P2017_long$isco08 >= 31 & P2017_long$isco08 <= 54) & P2017_long$sta == 1 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 42
P2017_long$eseg_2[(P2017_long$isco08 >= 71 & P2017_long$isco08 <= 96) & P2017_long$sta == 1 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 43

##Definition
#5	Clerks and skilled service workers  (status=e)
#5.1	General and numerical clerks and other clerical support employees  (ISCO 41, 43, 44)
#5.2	Customer services clerks  (ISCO 42)
#5.3	Personal care employees  (ISCO 53)
#5.4	Armed forced occupations and protective service employees  (ISCO 03 and ISCO 54)

P2017_long$eseg_2[(P2017_long$isco08 == 41 | P2017_long$isco08 == 43 | P2017_long$isco08 == 44) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 51
P2017_long$eseg_2[P2017_long$isco08 == 42 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 52
P2017_long$eseg_2[P2017_long$isco08 == 53 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 53
P2017_long$eseg_2[(P2017_long$isco08 == 03 | P2017_long$isco08 == 54) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 54

##Definition
#6	Industrial and agricultural employees  (status= e)
#6.1	Building and related trade employees  (ISCO 71)
#6.2	Food processing, wood working, garment employees  (ISCO 75)
#6.3	Metal, machinery, handicraft, printing, electrical and electronic trades employees  (ISCO 72, 73, 74)
#6.4	Stationary plant and machine operators and assemblers  (ISCO 81, 82)
#6.5	Drivers  (ISCO 83)

P2017_long$eseg_2[P2017_long$isco08 == 71 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 61
P2017_long$eseg_2[P2017_long$isco08 == 75 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 62
P2017_long$eseg_2[(P2017_long$isco08 == 72 | P2017_long$isco08 == 73 | P2017_long$isco08 == 74) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 63
P2017_long$eseg_2[(P2017_long$isco08 == 81 | P2017_long$isco08 == 82) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 64
P2017_long$eseg_2[P2017_long$isco08 == 83 & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 65

#Definition
#7	Less skilled workers (status= e)
#7.1	Personal services and sales employees (ISCO 51, 52)
#7.2	Blue collar employees and food preparation assistants in elementary occupations (ISCO 92, 93, 94, 96)  
#7.3	Cleaners and helpers and services employees in elementary occupations (ISCO 91, 95)
#7.4	Agricultural employees  (ISCO  6)

P2017_long$eseg_2[(P2017_long$isco08 == 51 | P2017_long$isco08 == 52) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 71
P2017_long$eseg_2[(P2017_long$isco08 == 92 | P2017_long$isco08 == 93 | P2017_long$isco08 == 94 | P2017_long$isco08 == 96) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 72
P2017_long$eseg_2[(P2017_long$isco08 == 91 | P2017_long$isco08 == 95) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 73
P2017_long$eseg_2[(P2017_long$isco08 >= 61 & P2017_long$isco08 <=63) & P2017_long$sta == 2 & P2017_long$eseg_1 > 0 & P2017_long$eseg_1 < 8] <- 74

##Definition
#8	Retired persons (and persons not employed  65 years or more)
#8.1	Retired Managers
#8.2	Retired professionals
#8.3	Retired technicians and associate professionals
#8.4	Retired small entrepreneurs
#8.5	Retired skilled service workers 
#8.6	Retired skilled blue-collars
#8.7	Retired less skilled workers
#8.8	Other inactive aged 65 or more

P2017_long$eseg_2[(((P2017_long$isco08 >= 11 & P2017_long$isco08 <=14) & (P2017_long$sta == 1 | P2017_long$sta == 2)) | (P2017_long$isco08 == 01 & P2017_long$sta == 2)) & P2017_long$eseg_1 == 8] <- 81
P2017_long$eseg_2[((P2017_long$isco08 >= 21 & P2017_long$isco08 <=26) & (P2017_long$sta == 1 | P2017_long$sta == 2)) & P2017_long$eseg_1 == 8] <- 82
P2017_long$eseg_2[(((P2017_long$isco08 >= 31 & P2017_long$isco08 <=35) & P2017_long$sta == 2) | (P2017_long$isco08 == 02 & P2017_long$sta == 2)) & P2017_long$eseg_1 == 8] <- 83
P2017_long$eseg_2[(P2017_long$isco08 >= 31 & P2017_long$isco08 <=96) & P2017_long$sta == 1 & P2017_long$eseg_1 == 8] <- 84
P2017_long$eseg_2[((P2017_long$isco08 >= 41 & P2017_long$isco08 <=44) | P2017_long$isco08 == 03 | P2017_long$isco08 == 53 | P2017_long$isco08 == 54) & P2017_long$sta == 2 & P2017_long$eseg_1 == 8] <- 85
P2017_long$eseg_2[(P2017_long$isco08 >= 71 & P2017_long$isco08 <=83) & P2017_long$sta == 2 & P2017_long$eseg_1 == 8] <- 86
P2017_long$eseg_2[(((P2017_long$isco08 >= 61 & P2017_long$isco08 <=63) | (P2017_long$isco08 >= 91 & P2017_long$isco08 <=96) | P2017_long$isco08 == 51 | P2017_long$isco08 == 52)) &
                    P2017_long$sta == 2 & P2017_long$eseg_1 == 8] <- 87
P2017_long$eseg_2[is.na(P2017_long$eseg_2) & P2017_long$eseg_1 == 8] <- 88

##Definition
#9	Other non employed persons
#9.1	Students
#9.2	Permanently disabled 
#9.3	Unemployed not elsewhere classified 
#9.4	Other inactive aged less than 65 years

P2017_long$eseg_2[P2017_long$PL031 == 6 & P2017_long$eseg_1 == 9] <- 91
P2017_long$eseg_2[P2017_long$PL031 == 8 & P2017_long$eseg_1 == 9] <- 92
P2017_long$eseg_2[P2017_long$PL031 == 5 & P2017_long$eseg_1 == 9] <- 93
P2017_long$eseg_2[(P2017_long$PL031 == 9 | P2017_long$PL031 == 10 | P2017_long$PL031 == 11) & P2017_long$eseg_1 == 9] <- 94
P2017_long$eseg_2[is.na(P2017_long$eseg_1)] <- NA

#generate label varaible for eseg_2
P2017_long$eseg_2_label <- NA
P2017_long$eseg_2_label[P2017_long$eseg_2 == 11] <- "11 Higher managerial self-employed"  
P2017_long$eseg_2_label[P2017_long$eseg_2 == 12] <- "12 Lower managerial self-employed" 
P2017_long$eseg_2_label[P2017_long$eseg_2 == 13] <- "13 Higher managerial employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 14] <- "14 Lower managerial employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 21] <- "21 Science, engineering and information and communications technology (ICT) professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 22] <- "22 Health professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 23] <- "23 Business and administration professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 24] <- "24 Legal, social and cultural professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 25] <- "25 Teaching professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 31] <- "31 Science, engineering and ICT technicians and associated professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 32] <- "32 Health associate professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 33] <- "33 Business and administration associate professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 34] <- "34 Legal, social and cultural associate professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 35] <- "35 Non-commissioned armed forces officers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 41] <- "41 Skilled agricultural self-employed workers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 42] <- "42 Technicians, clerical support, services and sales self-employed workers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 43] <- "43 Craft and related trades self-employed workers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 51] <- "51 General and numerical clerks and other clerical support employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 52] <- "52 Customer services clerks"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 53] <- "53 Personal care employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 54] <- "54 Armed forced occupations and protective service employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 61] <- "61 Building and related trade employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 62] <- "62 Food processing, wood working, garment employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 63] <- "63 Metal, machinery, handicraft, printing, electrical and electronic trades employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 64] <- "64 Stationary plant and machine operators and assemblers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 65] <- "65 Drivers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 71] <- "71 Personal services and sales employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 72] <- "72 Blue collar employees and food preparation assistants in elementary occupations"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 73] <- "73 Cleaners and helpers and services employees in elementary occupations"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 74] <- "74 Agricultural employees"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 81] <- "81 Retired Managers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 82] <- "82 Retired professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 83] <- "83 Retired technicians and associate professionals"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 84] <- "84 Retired small entrepreneurs"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 85] <- "85 Retired skilled white collars"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 86] <- "86 Retired skilled blue-collars"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 87] <- "87 Retired less skilled workers"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 88] <- "88 Other inactive aged 65 or more"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 91] <- "91 Students"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 92] <- "92 Permanently disabled"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 93] <- "93 Unemployed not elsewhere classified"
P2017_long$eseg_2_label[P2017_long$eseg_2 == 94] <- "94 Other inactive aged less than 65 years"


#Frequency Table eseg_2
table_eseg_2 <- data.frame(table(P2017_long$eseg_2_label, useNA = "always"))
View(table_eseg_2)

#Frequency Table eseg_2 by year
table_eseg_2_by_year <- data.frame(table(P2017_long$eseg_2_label, P2017_long$PB010, useNA = "always"))
table_eseg_2_by_year <- table_eseg_2_by_year %>%
  pivot_wider(names_from = Var2, values_from = Freq)
View(table_eseg_2_by_year)
